==> igniteui-angular-charts-16.1.2-beta.0.tgz: package/esm5/lib/Stacked100SplineSeries_combined.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { StackedSplineSeries } from "./StackedSplineSeries";
import { IStacked100Series_$type } from "./IStacked100Series";
import { markType } from "igniteui-angular-core";
import { Stacked100DataPreparer } from "./Stacked100DataPreparer";
import { StackedSplineSeriesView } from "./StackedSplineSeriesView";
import { Defaults } from "./Defaults";
/**
 * @hidden
 */
var Stacked100SplineSeries = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(Stacked100SplineSeries, _super);
    function Stacked100SplineSeries() {
        var _this = _super.call(this) || this;
        _this.ab = Stacked100SplineSeries.$;
        return _this;
    }
    Stacked100SplineSeries.prototype.by = function () {
        return new Stacked100SplineSeriesView(this);
    };
    Stacked100SplineSeries.prototype.l4 = function (a) {
        _super.prototype.l4.call(this, a);
        this.uy = a;
    };
    Stacked100SplineSeries.prototype.get_tx = function () {
        return true;
    };
    Stacked100SplineSeries.prototype.ac = function () {
        _super.prototype.ac.call(this);
        this.mn(false);
    };
    Stacked100SplineSeries.prototype.ud = function () {
        _super.prototype.ud.call(this);
        Stacked100DataPreparer.a(this);
    };
    Object.defineProperty(Stacked100SplineSeries.prototype, "useHighMarkerFidelity", {
        get: function () {
            return this.ss;
        },
        enumerable: false,
        configurable: true
    });
    Stacked100SplineSeries.$t = markType(Stacked100SplineSeries, 'Stacked100SplineSeries', StackedSplineSeries.$, [IStacked100Series_$type]);
    return Stacked100SplineSeries;
}(StackedSplineSeries));
export { Stacked100SplineSeries };
/**
 * @hidden
 */
var Stacked100SplineSeriesView = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(Stacked100SplineSeriesView, _super);
    function Stacked100SplineSeriesView(a) {
        return _super.call(this, a) || this;
    }
    Stacked100SplineSeriesView.prototype.as = function () {
        _super.prototype.as.call(this);
        if (!this.q) {
            this.c0.ql = Defaults.e;
        }
    };
    Stacked100SplineSeriesView.$t = markType(Stacked100SplineSeriesView, 'Stacked100SplineSeriesView', StackedSplineSeriesView.$);
    return Stacked100SplineSeriesView;
}(StackedSplineSeriesView));
export { Stacked100SplineSeriesView };

==> igniteui-angular-charts-17.2.0-beta.0.tgz: package/esm5/lib/Stacked100SplineSeries_combined.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { StackedSplineSeries } from "./StackedSplineSeries";
import { IStacked100Series_$type } from "./IStacked100Series";
import { markType } from "igniteui-angular-core";
import { Stacked100DataPreparer } from "./Stacked100DataPreparer";
import { StackedSplineSeriesView } from "./StackedSplineSeriesView";
import { Defaults } from "./Defaults";
/**
 * @hidden
 */
var Stacked100SplineSeries = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(Stacked100SplineSeries, _super);
    function Stacked100SplineSeries() {
        var _this = _super.call(this) || this;
        _this.ab = Stacked100SplineSeries.$;
        return _this;
    }
    Stacked100SplineSeries.prototype.cg = function () {
        return new Stacked100SplineSeriesView(this);
    };
    Stacked100SplineSeries.prototype.o0 = function (a) {
        _super.prototype.o0.call(this, a);
        this.yo = a;
    };
    Stacked100SplineSeries.prototype.get_xn = function () {
        return true;
    };
    Stacked100SplineSeries.prototype.ac = function () {
        _super.prototype.ac.call(this);
        this.pp(false);
    };
    Stacked100SplineSeries.prototype.x3 = function () {
        _super.prototype.x3.call(this);
        Stacked100DataPreparer.a(this);
    };
    Object.defineProperty(Stacked100SplineSeries.prototype, "useHighMarkerFidelity", {
        get: function () {
            return this.wi;
        },
        enumerable: false,
        configurable: true
    });
    Stacked100SplineSeries.$t = markType(Stacked100SplineSeries, 'Stacked100SplineSeries', StackedSplineSeries.$, [IStacked100Series_$type]);
    return Stacked100SplineSeries;
}(StackedSplineSeries));
export { Stacked100SplineSeries };
/**
 * @hidden
 */
var Stacked100SplineSeriesView = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(Stacked100SplineSeriesView, _super);
    function Stacked100SplineSeriesView(a) {
        return _super.call(this, a) || this;
    }
    Stacked100SplineSeriesView.prototype.au = function () {
        _super.prototype.au.call(this);
        if (!this.q) {
            this.c3.ua = Defaults.e;
        }
    };
    Stacked100SplineSeriesView.$t = markType(Stacked100SplineSeriesView, 'Stacked100SplineSeriesView', StackedSplineSeriesView.$);
    return Stacked100SplineSeriesView;
}(StackedSplineSeriesView));
export { Stacked100SplineSeriesView };
